import React, { useState } from "react";
import styles from "./index.less";
import { Flex, Space } from "antd";
import classNames from "classnames";
import { getColor } from "@/utils";

/** @name 区域分布 */
const RegionalDistribution: React.FC = () => {
  const [curLocation, setCurLocation] = useState<"forward" | "back">("forward");

  const barProgress = (value: number, color: string) => {
    return (
      <>
        <div className={styles.barValue} style={{ color: color }}>
          {value}
        </div>
        <div className={styles.progress}>
          <div
            className={styles.bar}
            style={{ height: `${value}%`, backgroundColor: color }}
          ></div>
        </div>
      </>
    );
  };

  const data = [
    {
      label: "双流区",
      value: 98.5,
    },
    {
      label: "双流区",
      value: 98.5,
    },
    {
      label: "双流区",
      value: 85.5,
    },
    {
      label: "双流区",
      value: 98.5,
    },
    {
      label: "双流区",
      value: 82,
    },
  ];

  return (
    <div className={styles.container}>
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>区域CQI分布</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "forward" && styles.select
            )}
            onClick={() => setCurLocation("forward")}
          >
            前5
          </div>
          <div
            className={classNames(
              styles.radio,
              curLocation === "back" && styles.select
            )}
            onClick={() => setCurLocation("back")}
          >
            后5
          </div>
        </Space>
      </Flex>
      <Flex
        align="center"
        justify="space-evenly"
        className={styles.barContainer}
      >
        {data.map((item, index) => {
          return (
            <div key={index} className={styles.barItem}>
              {barProgress(item.value, getColor(item.value)!)}
              <div className={styles.barChartLabel}>{item.label}</div>
            </div>
          );
        })}
      </Flex>
    </div>
  );
};

export default RegionalDistribution;
