import React, { useRef, useState } from "react";
import styles from "./index.less";
import { Flex, message, Space } from "antd";
import classNames from "classnames";

import CleanRangeModal, { CleanRangeModalMethod } from "../CleanRangeModal";
import { useBoolean } from "ahooks";

/** @name 领域事件态势分布 */
const DomainEventSituationDistribution: React.FC = () => {
  const [curLocation, setCurLocation] = useState<"today">("today");

  const CleanRef = useRef<CleanRangeModalMethod>(null);

  const menu = [
    {
      name: "清扫保洁",
      value: 986,
      icon: require("@/assets/images/solidWaste/qingshao.png"),
      onClick: () => {
        CleanRef.current?.show();
      },
    },
    {
      name: "垃圾处置",
      value: 986,
      icon: require("@/assets/images/solidWaste/lajichuzhi.png"),
    },
    {
      name: "餐厨垃圾",
      value: 986,
      icon: require("@/assets/images/solidWaste/canculaji.png"),
    },
    {
      name: "扬尘监管",
      value: 986,
      icon: require("@/assets/images/solidWaste/yangchenjianguan.png"),
    },
  ];

  return (
    <div className={styles.container}>
      <CleanRangeModal ref={CleanRef}></CleanRangeModal>
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>领域事件态势分布</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "today" && styles.select
            )}
            onClick={() => setCurLocation("today")}
          >
            今日
          </div>
        </Space>
      </Flex>
      <Flex gap={20} className={styles.listWrap}>
        {menu.map((item, index) => {
          return (
            <div
              className={styles.GradientBorder}
              key={index}
              onClick={() => {
                item.onClick ? item.onClick() : message.warning("页面待开发");
              }}
            >
              <div className={styles.itemCard} key={index}>
                <Space>
                  <div className={styles.itemVal}>{item.value}</div>
                  <div className={styles.itemUnit}>件</div>
                </Space>
                <div className={styles.itemName}>{item.name}</div>
                <div className={styles.itemImgWrap}>
                  <img src={item.icon} alt=""></img>
                </div>
              </div>
            </div>
          );
        })}
      </Flex>
    </div>
  );
};

export default DomainEventSituationDistribution;
