import React, { useState } from "react";
import styles from "./index.less";
import { Flex, Space } from "antd";
import classNames from "classnames";
import { getColor } from "@/utils";
import BaseDesc from "@/components/BaseDesc";
import ReactECharts from "echarts-for-react";
import { lineOption } from "./option";

/** @name 问题概况 */
const ProblemOverview: React.FC = () => {
  const [curLocation, setCurLocation] = useState<"today">("today");

  return (
    <div className={styles.container}>
      <Flex justify="space-between" className={styles.header} align="center">
        <div className={styles.title}>问题概况</div>
        <Space>
          <div
            className={classNames(
              styles.radio,
              curLocation === "today" && styles.select
            )}
            onClick={() => setCurLocation("today")}
          >
            今日
          </div>
        </Space>
      </Flex>
      <Flex className={styles.infoWrap} justify="space-between">
        <div>
          <BaseDesc
            value={262}
            name="问题总数"
            unit="件"
            align="center"
          ></BaseDesc>
        </div>
        <div>
          <BaseDesc
            value={22}
            name="待处置"
            align="center"
            unit="件"
          ></BaseDesc>
        </div>
        <div>
          <BaseDesc
            value={89.2}
            name="处置率"
            align="center"
            unit="%"
          ></BaseDesc>
        </div>
      </Flex>
      <div className={styles.barChart}>
        <ReactECharts
          option={lineOption}
          style={{ width: "100%", height: 180 }}
        ></ReactECharts>
      </div>
    </div>
  );
};

export default ProblemOverview;
