import { useMemo } from "react";
import ReactECharts from "echarts-for-react";

import * as echarts from "echarts";
import styles from "./index.less";
import { Flex } from "antd";
import { gaugeOption, barOption } from "./option";
import { getColor } from "@/utils";
/** @name 成都市环卫固废态势总览 */
const SituationOverview = () => {
  const dataSource = [...Array(20)].map((_, i) => {
    return {
      value: Math.floor(Math.random() * 100),
      name: "xx区" + i,
    };
  });

  const newBarOption = useMemo(() => {
    // expensive calculation
    const xAxisData = dataSource.map((item) => item.name);
    const seriesData = dataSource.map((item) => ({
      ...item,
      itemStyle: {
        color: getColor(item.value),
      },
    }));
    (barOption.series as echarts.SeriesOption[])[0].data = seriesData;
    (barOption.xAxis as any[])[0].data = xAxisData;
    return barOption;
  }, []);

  return (
    <div className={styles.container}>
      <Flex align="center" justify="space-between">
        <div className={styles.header_title}>成都市环卫固废态势总览</div>
        <div className={styles.header_time}>更新时间 2024-10-09 10:20:20</div>
      </Flex>
      <Flex align="center" justify="center" className={styles.gaugeChart}>
        <ReactECharts
          style={{ width: 500, height: 150 }}
          option={gaugeOption}
        />
        <div className={styles.chart_status}>理想态</div>
      </Flex>
      <div className={styles.gaugeTitle}>环卫固废今日体征指数</div>
      <div className={styles.barChart}>
        <ReactECharts
          option={newBarOption}
          style={{ width: "100%", height: 150 }}
        ></ReactECharts>
      </div>
    </div>
  );
};

export default SituationOverview;
